@@ -1,4 +1,5 @@
-from nameless import main
+from nameless.__main__ import main
+
 
 def test_main():
-    assert main([]) == 0
\ No newline at end of file
+    assert main([]) == 0
